@@ -25,13 +25,17 @@ pub const MAX_MAC_COUNT: usize = 32_000;
 /// Max allowed clients count
 pub const MAX_NEXTHOP_COUNT: usize = 3000;
 /// Max mac entry aging timeout
-pub const MAX_MAC_AGING_TIMEOUT: u64 = 600; // 5 minutes
+pub const MAX_MAC_AGING_TIMEOUT: u64 = 600; // 10 minutes
 /// Session keepalive timeout
 pub const KEEPALIVE_TIMEOUT: u64 = 30;
 /// Session keepalive interval
 pub const KEEPALIVE_INTERVAL: u64 = 10;
 /// Session keepalive control packet data
 pub const KEEPALIVE_PACKET: &[u8] = "KEEPALIVE".as_bytes();
+/// Session hello timeout
+pub const HELLO_TIMEOUT: u64 = 180;
+/// Session hello interval
+pub const HELLO_INTERVAL: u64 = 3;
 /// Session hello control packet data for client registration
 pub const HELLO_PACKET: &[u8] = "HELLO".as_bytes();
 /// Session bye control packet data for client registration
